@@ -369,58 +369,3 @@ foreach n [list {idx}] {{
         for i in self.labelidx[::-1]:
             vmd.send(f"label delete Atoms {i}")
             VMDLabels.count -= 1
-
-
-# Practically only testing execution of the classes
-class _TestVMDGraphics(unittest.TestCase):
-    @classmethod
-    def setUpClass(self):
-        from moleculekit.molecule import Molecule
-
-        self.viewer = getCurrentViewer(dispdev="text")
-        self.mol3PTB = Molecule("3PTB")
-
-    def test_convex_hull(self):
-        VMDConvexHull(self.mol3PTB)
-        VMDConvexHull(self.mol3PTB, solid=True)
-
-    def test_box(self):
-        VMDBox([0, 10, -5, 3, 100, 400])
-
-    def test_text(self):
-        VMDText("test text", [10, -3.4, 6])
-
-    def test_isosurface(self):
-        import numpy as np
-
-        VMDIsosurface(np.random.rand(3, 4, 2), [-1, 25, 3], [1, 1, 1])
-
-    def test_labels(self):
-        VMDLabels(self.mol3PTB, "resname BEN")
-
-    def test_sphere(self):
-        VMDSphere([0, -5.3, 195], radius=6)
-
-
-if __name__ == "__main__":
-    """
-    from moleculekit.molecule import Molecule
-    import moleculekit.vmdgraphics
-
-    m=Molecule("3PTB")
-    m.view()
-    mf=m.copy()
-    mf.filter("protein")
-    mgh=moleculekit.vmdgraphics.VMDConvexHull(mf)
-
-    n=Molecule("1JNO")
-    n.view()
-    nf=n.copy()
-    nf.filter("protein")
-    ngh=moleculekit.vmdgraphics.VMDConvexHull(nf,solid=True)
-
-    """
-    unittest.main(verbosity=2)
-    # from moleculekit.molecule import Molecule
-    # import doctest
-    # doctest.testmod()
